sol.models.match – Matches — SoL 3 developers documentation

# `sol.models.match` – Matches

class `sol.models.match.` `Match`(**kwargs)

  A single match.

  This table contains all the matches played in the various rounds of a tourney. A match may be between two different competitors or between a competitor and a placeholder, when the number of competitors is odd.

  `board`

    The number of the carromboard this match is played on.

  `caption`(html=None, localized=True, omit_competitor_decoration=False)

    A description of the match, made up with the description of each competitor.

  `competitor1`

    First `competitor`

  `competitor1FullName`

    Full name of the first `competitor`

  `competitor2`

    Second `competitor` (may be `None`, the Phantom).

  `competitor2FullName`

    Full name of the second `competitor`

  `description`

    A description of the match, made up with the description of each competitor.

  `final`

    Whether the match is a normal one or a final.

  `idcompetitor1`

    First `competitor`‘s ID.

  `idcompetitor2`

    Second `competitor`‘s ID (possibly None).

  `idmatch`

    Primary key.

  `idtourney`

    Related `tourney`‘s ID.

  `results`()

    Results of this match, comparing competitor’ scores.

    Return type: | tuple
    Returns: | winner, loser, netscore

  `score1`

    Score of the first `competitor`.

  `score2`

    Score of the second `competitor`.

  `serialize`(serializer, competitors)

    Reduce a single match to a simple dictionary.

    Parameters: | serializer – a `Serializer` instance competitors – a mapping between competitor integer ID to its integer marker
    Return type: | dict
    Returns: | a plain dictionary containing a flatified view of this match

  `turn`

    Round number of the match.